@@ -14,7 +14,7 @@ class Core:
     def __init__(
         self, username: str = "", pwd: str = "", cookie: str = None
     ) -> None:
-        logging.info("🚀 Init Core")
+        logging.info("Init Core")
         self.__processor = Processor()
         self.__request = Request()
         self.__api_url = ApiUrl()
